@@ -3,10 +3,13 @@ use strict;
 use warnings;
 use base qw/Pod::Parser Class::Accessor::Fast Class::Data::Inheritable/;
 use Pod::ParseUtils;
+use File::Spec;
+use File::Basename;
+use Pod::ProjectDocs::Template;
 
 # most of code is borrowed from Pod::Xhtml
-__PACKAGE__->mk_accessors(qw/components/);
-__PACKAGE__->mk_classdata($_) for qw/COMMANDS SEQ/;
+__PACKAGE__->mk_accessors(qw/components local_modules current_files_output_path/);
+__PACKAGE__->mk_classdata($_) for qw/COMMANDS SEQ language/;
 
 __PACKAGE__->COMMANDS( {
     map { $_ => 1 } qw/pod head1 head2 head3 head4 item over back for begin end/
@@ -24,10 +27,6 @@ __PACKAGE__->SEQ( {
     Z => \&seqZ,
 } );
 
-sub gen_html {
-    my($self, %args) = @_;
-}
-
 ########## New PUBLIC methods for this class
 sub asString { my $self = shift; return $self->{buffer}; }
 sub asStringRef { my $self = shift; return \$self->{buffer}; }
@@ -528,7 +527,6 @@ sub seqL {
     my ($self, $link) = @_;
     $self->{LinkParser}->parse( $link );
 
-    my $page = _htmlEscape( $self->{LinkParser}->page );
     my $kind = $self->{LinkParser}->type;
     my $string = '';
 
@@ -536,25 +534,45 @@ sub seqL {
         my $targ = _htmlEscape( $self->{LinkParser}->node );
         my $text = _htmlEscape( $self->{LinkParser}->text );
         $string = qq(<a href="$targ">$text</a>);
-    } elsif ($page eq '') {    # a link to this page
+    } elsif ($self->{LinkParser}->page eq '') {    # a link to this page
         # Post-process these links so we can things up to the correct sections
         my $targ = $self->{LinkParser}->node;
-        $string = $self->{LinkParser}->markup;
-        $string =~ s|Q<(.+?)>|qq(<a href="#<<<$targ>>>">) . _htmlEscape( $1 ) . '</a>'|e;
-    } elsif ($link !~ /\|/) {    # a link off-page with _no_ alt text
-        $string = $self->{LinkParser}->markup;
-        $string =~ s|Q<(.+?)>|'<b>' . _htmlEscape( $1 ) . '</b>'|e;
-        $string =~ s|P<(.+?)>|'<cite>' . _htmlEscape( $1 ) . '</cite>'|e;
-    } else {    # a link off-page with alt text
         my $text = _htmlEscape( $self->{LinkParser}->text );
-        my $targ = _htmlEscape( $self->{LinkParser}->node );
-        $string = "<b>$text</b> (";
-        $string .= "<b>$targ</b> in " if $targ;
-        $string .= "<cite>$page</cite>)";
+        $string = qq(<a href="#<<<$targ>>>">$text</a>);
+    } elsif ($kind eq 'item') {    # link to the other page
+        my $targ = $self->_resolvePage($self->{LinkParser}->page);
+        my $node = $self->{LinkParser}->node;
+        my $text = _htmlEscape( $self->{LinkParser}->text );
+        $string = qq(<a href="$targ#$node">$text</a>);
+    } else {
+        my $targ = $self->_resolvePage($self->{LinkParser}->page);
+        my $text = _htmlEscape( $self->{LinkParser}->text );
+        $string = qq(<a href="$targ">$text</a>);
     }
     return $string;
 }
 
+sub _resolvePage {
+    my ($self, $page) = @_;
+    my $modules = $self->local_modules->{ $self->language } || [];
+    foreach my $module ( @$modules ) {
+        if ( $module->{name} eq $page ) {
+            my $targ = $self->_resolveRelPath( $module->{path} );
+            return $targ;
+        }
+    }
+    return $self->_makeLinkToCommunity($page);
+}
+
+sub _makeLinkToCommunity { "abstract method" }
+
+sub _resolveRelPath {
+    my ($self, $path ) = @_;
+    my $curpath = $self->current_files_output_path;
+    my ($name, $dir) = File::Basename::fileparse $curpath, qr/\.html/;
+    return File::Spec->abs2rel($path, $dir);
+}
+
 sub seqS {
     my $text = $_[1];
     $text =~ s/\s/&nbsp;/g;
@@ -587,6 +605,71 @@ sub seqE {
     return $rv;
 }
 
+sub gen_html {
+    my($self, %args) = @_;
+    my $doc        = $args{doc};
+    my $components = $args{components};
+    my $mgr_desc   = $args{desc};
+
+    $self->current_files_output_path( $doc->get_output_path );
+
+    $self->_prepare($doc, $components, $mgr_desc);
+#    local $SIG{__WARN__} = sub { };
+    $self->parse_from_file($doc->origin);
+    my $title = $self->_get_title;
+    $doc->title($title);
+
+    $self->current_files_output_path('');
+
+    return $self->asString;
+}
+
+sub _prepare {
+    my($self, $doc, $components, $mgr_desc) = @_;
+    my $charset = $doc->config->charset || 'UTF-8';
+    $self->{StringMode} = 1;
+    $self->{MakeMeta}   = 0;
+    $self->{TopLinks}   = $components->{arrow}->tag($doc);
+    $self->{MakeIndex}  = $doc->config->index;
+    $self->initialize();
+    $self->addHeadText($components->{css}->tag($doc));
+    $self->addHeadText(qq|<meta http-equiv="Content-Type" content="text/html; charset=$charset" />\n|);
+    $self->addBodyOpenText($self->_get_data($doc, $mgr_desc));
+	$self->addBodyCloseText(qq|<div class="footer">generated by <a href="http://search.cpan.org/~lyokato/Pod-ProjectDocs/">Pod::ProjectDocs</a></div>|);
+}
+
+sub _get_title {
+    my $self = shift;
+    my $name_node = 0;
+    my $title = '';
+    foreach my $node ( @{ $self->parse_tree } ) {
+        if ($node->{'-ptree'}[0] && $node->{'-ptree'}[0] eq 'NAME') {
+            $name_node = 1; next;
+        }
+        if($name_node == 1){
+            $title = join "", @{ $node->{'-ptree'} };
+            last;
+        }
+    }
+    $title =~ s/^\s*\S*\s*-\s(.*)$/$1/;
+    return $title;
+}
+
+sub _get_data {
+    my($self, $doc, $mgr_desc) = @_;
+    my $tt = Pod::ProjectDocs::Template->new;
+    my $text = $tt->process($doc, $doc->data, {
+        title    => $doc->config->title,
+        desc     => $doc->config->desc,
+        name     => $doc->name,
+        outroot  => $doc->config->outroot,
+        src      => $doc->get_output_src_path,
+        mgr_desc => $mgr_desc,
+    });
+    return $text;
+}
+
+
 1;
 __END__
 
